@@ -12,5 +12,7 @@ finally:
 
 
 from nessvec import util
-from nessvec import nessvectors_glove as glove  # noqa
+from nessvec import glove  # noqa
+
+__all__ = [util, glove]
 # from nessvec import nessvectors as word2vec  # noqa
